"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = __importStar(require("fs"));
const log4js = __importStar(require("log4js"));
const events_1 = __importDefault(require("events"));
const logger = log4js.getLogger();
class SettingStore extends events_1.default {
    constructor() {
        super();
        this.state = {
            adapter: 'mysql',
            host: null,
            port: null,
            user: null,
            database: null,
            password: null
        };
    }
    static getInstance() {
        if (SettingStore.instance) {
            return SettingStore.instance;
        }
        SettingStore.instance = new SettingStore();
        return SettingStore.instance;
    }
    getSetting() {
        return Object.assign({}, this.state);
    }
    setSettingFromFile(path) {
        return new Promise((resolve, reject) => {
            fs.stat(path, (err, _stat) => {
                if (err) {
                    if (err.code && err.code === 'ENOENT') {
                        logger.debug("there isn't config file.");
                        resolve();
                        return;
                    }
                    logger.error(err.message);
                    reject(err);
                    return;
                }
                fs.readFile(path, { encoding: 'utf8' }, (err, data) => {
                    if (err) {
                        logger.error(err.message);
                        reject(err);
                        return;
                    }
                    this.setSetting(JSON.parse(data));
                    logger.debug(`read settings from ${path}`);
                    logger.debug(JSON.stringify(this.getSetting()));
                    resolve(this.getSetting());
                    return;
                });
            });
        });
    }
    setSetting(setting) {
        this.state = Object.assign({}, this.state, setting);
        this.emit('change', this.state);
    }
}
exports.default = SettingStore;
//# sourceMappingURL=SettingStore.js.map